@@ -44,9 +44,9 @@ def read_args():
     parser.add_argument('--folder', metavar='PATH', default='.', help='Path to simulation folder (this is where you keep your stosim.conf), defaults to "."')
     parser.add_argument('--simulations', metavar='NAME', nargs='*', help='names of subsimulations (the filenames of their configuration files without the ".conf" ending).')
     parser.add_argument('--run', action='store_true', help='Only run, do not analyse.')
-    parser.add_argument('--check', action='store_true', help='Check status of simulations.')
+    parser.add_argument('--status', action='store_true', help='Check status of simulations.')
     parser.add_argument('--resume', action='store_true', help='Resume control of simulation scheduling.')
-    parser.add_argument('--kill', action='store_true', help='Kill simulation.')
+    parser.add_argument('--kill', action='store_true', help='Kill simulations.')
     parser.add_argument('--list', action='store_true', help='List number of runs made so far, per configuration.')
     parser.add_argument('--more', action='store_true', help='Add more runs to current state of config and data.')
     parser.add_argument('--plots', metavar='FIGURE', nargs='*', type=int, help='Make plots (needs gnuplot and eps2pdf installed). Add indices of figures as arguments if you only want to generate specific ones.')
@@ -55,8 +55,14 @@ def read_args():
     parser.add_argument('-d', action='store_true', help='delete old data without confirmation.')
 
     # Stosim might get called from code and then we might parse totally different commands
-    # than expected. Thus, let's not break in that case and ignore unknown args.
-    return parser.parse_known_args()[0]
+    # than expected. Thus, we let some arguments thourhg (e.g. 'test' for unit testing)
+    parsed = parser.parse_known_args()
+    if len(parsed[1]) > 0 and not 'test' in parsed[1]: 
+        print("[StoSim] Unknown argument(s): {}".format(','.join(parsed[1])))
+        parser.print_usage()
+        sys.exit(0)
+    else:
+        return parsed[0]
 
 
 def check_for_older_data(simfolder, more=False):
